@@ -33,7 +33,7 @@ def evaluation(
         batch_size=batch_size,
         eval_central_crop=central_crop,
         resize_method=resize_method,
-        eval_antialias=antialias,
+        resize_antialias=antialias,
         rescale_mode=rescale_mode,
     )
 
@@ -53,8 +53,8 @@ def evaluation(
     return y_true, y_pred_top_1, y_pred_top_5
 
 
-def parse_timm_log(log_filee):
-    with open(log_filee, "r") as ff:
+def parse_timm_log(log_file, pick_keys=None):
+    with open(log_file, "r") as ff:
         aa = ff.readlines()
 
     """ Find pattern for train epoch end """
@@ -92,7 +92,8 @@ def parse_timm_log(log_filee):
     # val_acc = [float(ii.split('Acc@1:')[1].strip().split("Acc@5:")[0].split("(")[1].split(")")[0]) for ii in aa if test_epoch_end_pattern in ii]
 
     # print(f"{len(train_loss) = }, {len(lr) = }, {len(val_loss) = }, {len(val_acc) = }")
-    return {"loss": train_loss, "lr": lr, "val_loss": val_loss, "val_acc": val_acc}
+    hh = {"loss": train_loss, "lr": lr, "val_loss": val_loss, "val_acc": val_acc}
+    return hh if pick_keys is None else {kk: hh[kk] for kk in pick_keys}
 
 
 def combine_hist_into_one(hist_list, save_file=None):
@@ -111,19 +112,20 @@ def combine_hist_into_one(hist_list, save_file=None):
     return hh
 
 
-def plot_and_peak_scatter(ax, array, peak_method, label, color=None, va="bottom", **kwargs):
+def plot_and_peak_scatter(ax, array, peak_method, label, skip_first=0, color=None, va="bottom", **kwargs):
+    array = array[skip_first:]
     for id, ii in enumerate(array):
         if tf.math.is_nan(ii):
             array[id] = array[id - 1]
-    ax.plot(array, label=label, color=color, **kwargs)
+    ax.plot(range(skip_first, skip_first + len(array)), array, label=label, color=color, **kwargs)
     color = ax.lines[-1].get_color() if color is None else color
     pp = peak_method(array)
     vv = array[pp]
-    ax.scatter(pp, vv, color=color, marker="v")
-    ax.text(pp, vv, "{:.4f}".format(vv), va=va, ha="right", color=color, fontsize=9, rotation=0)
+    ax.scatter(pp + skip_first, vv, color=color, marker="v")
+    ax.text(pp + skip_first, vv, "{:.4f}".format(vv), va=va, ha="right", color=color, fontsize=9, rotation=0)
 
 
-def plot_hists(hists, names=None, base_size=6, addition_plots=["lr"], text_va=["bottom"]):
+def plot_hists(hists, names=None, base_size=6, addition_plots=["lr"], text_va=["bottom"], skip_first=0):
     import os
     import json
     import matplotlib.pyplot as plt
@@ -142,19 +144,21 @@ def plot_hists(hists, names=None, base_size=6, addition_plots=["lr"], text_va=["
                 hist = json.load(ff)
         name = name if name != None else str(id)
 
-        plot_and_peak_scatter(axes[0], hist["loss"], peak_method=np.argmin, label=name + " loss", color=None, va=cur_va)
+        plot_and_peak_scatter(axes[0], hist["loss"], np.argmin, name + " loss", skip_first, color=None, va=cur_va)
         color = axes[0].lines[-1].get_color()
-        if "val_loss" not in addition_plots:
-            plot_and_peak_scatter(axes[0], hist["val_loss"], np.argmin, label=name + " val_loss", color=color, va=cur_va, linestyle="--")
+        val_loss = hist.get("val_loss", [])
+        if len(val_loss) > 0 and "val_loss" not in addition_plots:
+            plot_and_peak_scatter(axes[0], val_loss, np.argmin, name + " val_loss", skip_first, color, va=cur_va, linestyle="--")
         acc = hist.get("acc", hist.get("accuracy", []))
         if len(acc) > 0:  # For timm log
-            plot_and_peak_scatter(axes[1], acc, peak_method=np.argmax, label=name + " accuracy", color=color, va=cur_va)
+            plot_and_peak_scatter(axes[1], acc, np.argmax, name + " accuracy", skip_first, color=color, va=cur_va)
         val_acc = hist.get("val_acc", hist.get("val_accuracy", []))
-        plot_and_peak_scatter(axes[1], val_acc, peak_method=np.argmax, label=name + " val_accuracy", color=color, va=cur_va, linestyle="--")
+        plot_and_peak_scatter(axes[1], val_acc, np.argmax, name + " val_accuracy", skip_first, color=color, va=cur_va, linestyle="--")
         if addition_plots is not None and len(addition_plots) != 0:
             for id, ii in enumerate(addition_plots):
-                peak_method = np.argmin if "loss" in ii else np.argmax
-                plot_and_peak_scatter(axes[2 + id], hist[ii], peak_method=peak_method, label=name + " " + ii, color=color, va=cur_va)
+                if len(hist.get(ii, [])) > 0:
+                    peak_method = np.argmin if "loss" in ii else np.argmax
+                    plot_and_peak_scatter(axes[2 + id], hist[ii], peak_method, name + " " + ii, skip_first, color=color, va=cur_va)
     for ax in axes:
         ax.legend()
         ax.grid(True)
