@@ -5,7 +5,11 @@ from keras_cv_attention_models.download_and_load import reload_model_weights
 BATCH_NORM_EPSILON = 1e-5
 
 PRETRAINED_DICT = {
-    "mlp_mixer_b16": {"imagenet21k": "6353dffc590a2a7348a44cee2c784724", "imagenet": "abd04090063ba9ab0d49e2131cef9d64", "imagenet_sam": "d953ef41ffdb0ab9c3fa21493bf0982f"},
+    "mlp_mixer_b16": {
+        "imagenet21k": "6353dffc590a2a7348a44cee2c784724",
+        "imagenet": "abd04090063ba9ab0d49e2131cef9d64",
+        "imagenet_sam": "d953ef41ffdb0ab9c3fa21493bf0982f",
+    },
     "mlp_mixer_l16": {"imagenet": "fa91a74f1aa11ed610299d06d643ed45", "imagenet21k": "8dca5de1817112d9e717db6b2e9a7b0b"},
     "mlp_mixer_b32": {"imagenet_sam": "a6285750e55579fc68e7ba68a683c77d"},
 }
