@@ -32,7 +32,8 @@ def outlook_attention(inputs, embed_dim, num_heads=8, kernel_size=3, padding=1,
     attn = keras.layers.Dense(kernel_size ** 4 * num_heads, name=name + "attn")(attn) / qk_scale
     # [1, 14, 14, 6, 9, 9]
     attn = tf.reshape(attn, (-1, hh, ww, num_heads, kernel_size * kernel_size, kernel_size * kernel_size))
-    attention_weights = tf.nn.softmax(attn, axis=-1)
+    # attention_weights = tf.nn.softmax(attn, axis=-1)
+    attention_weights = keras.layers.Softmax(axis=-1, name=name and name + "attention_scores")(attn)
     if attn_dropout > 0:
         attention_weights = keras.layers.Dropout(attn_dropout)(attention_weights)
 
@@ -91,7 +92,8 @@ def outlook_attention_simple(inputs, embed_dim, num_heads=6, kernel_size=3, attn
     attn = keras.layers.AveragePooling2D(pool_size=kernel_size, strides=kernel_size)(inputs)
     attn = keras.layers.Dense(kernel_size ** 4 * num_heads, use_bias=True, name=name + "attn")(attn) / qk_scale
     attn = tf.reshape(attn, [-1, hh, ww, num_heads, kernel_size * kernel_size, kernel_size * kernel_size])  # [1, 14, 14, 6, 4, 4]
-    attn = tf.nn.softmax(attn, axis=-1)
+    # attn = tf.nn.softmax(attn, axis=-1)
+    attn = keras.layers.Softmax(axis=-1, name=name and name + "attention_scores")(attn)
     if attn_dropout > 0:
         attn = keras.layers.Dropout(attn_dropout)(attn)
 
@@ -195,7 +197,11 @@ class PositionalEmbedding(keras.layers.Layer):
 
     def load_resized_pos_emb(self, source_layer):
         # For input 224 --> [1, 14, 14, 384], convert to 384 --> [1, 24, 24, 384]
-        self.pp.assign(tf.image.resize(source_layer.pp, self.pp.shape[1:3]))
+        if isinstance(source_layer, dict):
+            source_pp = source_layer["positional_embedding:0"]  # weights
+        else:
+            source_pp = source_layer.pp  # layer
+        self.pp.assign(tf.image.resize(source_pp, self.pp.shape[1:3]))
 
 
 @tf.keras.utils.register_keras_serializable(package="volo")
